@@ -5,7 +5,7 @@ use HTTP::Cookies;
 use LWP::UserAgent;
 
 use vars qw($VERSION);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 my $countries = {
   'afghanistan' => 'afghanistan',
@@ -518,8 +518,8 @@ WWW::Gazetteer::Calle - Find location of world towns and cities
 
 =head1 SYNOPSYS
 
-  use WWW::Gazetteer::Calle;
-  my $g = WWW::Gazetteer::Calle->new();
+  use WWW::Gazetteer;
+  my $g = WWW::Gazetteer::Calle->new('calle');
   my @londons = $g->find(UK => 'London');
   my $london = $londons[0];
   print $london->{longitude}, ", ", $london->{latitude}, "\n";
@@ -534,9 +534,11 @@ http://www.calle.com/world/ to return geographical location
 (longitude, latitude, elevation) for towns and cities in countries in
 the world.
 
-Once you have imported the module and created a gazetteer object,
-calling find($country => $town) will return a list of hashrefs with
-longitude and latitude information.
+This module is a subclass of C<WWW::Gazetteer>, so you must use that
+to create a C<WWW::Gazetteer::Calle> object. Once you have imported
+the module and created a gazetteer object, calling find($country =>
+$town) will return a list of hashrefs with longitude and latitude
+information.
 
   my @londons = $g->find(UK => 'London');
   my $london = $londons[0];
@@ -565,13 +567,13 @@ the Prime Meridian and the equator.
 This returns a new WWW::Gazetteer::Calle object. It currently has no
 arguments:
 
-  use WWW::Gazetteer::Calle;
-  my $g = WWW::Gazetteer::Calle->new();
+  use WWW::Gazetteer;
+  my $g = WWW::Gazetteer->new('calle');
 
 =head2 find()
 
 The find method looks up geographical information and returns it to
-you. It takes in a city and a country, with the recommended syntax
+you. It takes in a country and a city, with the recommended syntax
 being ISO 3166 code and city name. However, it also tries to do what
 you mean.
 
